searchData={"items":[{"type":"module","title":"SwarmEx","doc":"SwarmEx is an Elixir library for lightweight, controllable, and testable AI agent orchestration.\n\nIt provides a simple API for creating and managing networks of AI agents, with features including:\n\n- Agent lifecycle management\n- Message routing between agents\n- Tool integration and execution\n- Network state management\n- Error handling and recovery","ref":"SwarmEx.html"},{"type":"module","title":"Example - SwarmEx","doc":"# Create a new agent network\n    {:ok, network} = SwarmEx.create_network()\n\n    # Define an agent\n    defmodule MyAgent do\n      use SwarmEx.Agent\n\n      def init(opts), do: {:ok, opts}\n\n      def handle_message(msg, state) do\n        {:ok, \"Echo: #{msg}\", state}\n      end\n\n      def handle_tool(:example, args, state) do\n        {:ok, args, state}\n      end\n    end\n\n    # Add an agent to the network\n    {:ok, agent_pid} = SwarmEx.create_agent(network, MyAgent)\n\n    # Send a message to the agent\n    {:ok, response} = SwarmEx.send_message(agent_pid, \"Hello!\")","ref":"SwarmEx.html#module-example"},{"type":"function","title":"SwarmEx.create_agent/3","doc":"Creates a new agent in the given network.","ref":"SwarmEx.html#create_agent/3"},{"type":"function","title":"Options - SwarmEx.create_agent/3","doc":"* `:name` - Optional name for the agent\n  * `:tools` - List of tools available to the agent\n  * `:instruction` - Base instruction/prompt for the agent\n  * All other options are passed to the agent's init/1 callback","ref":"SwarmEx.html#create_agent/3-options"},{"type":"function","title":"Examples - SwarmEx.create_agent/3","doc":"{:ok, agent} = SwarmEx.create_agent(network, MyAgent)\n    {:ok, agent} = SwarmEx.create_agent(network, MyAgent, name: \"processor\")","ref":"SwarmEx.html#create_agent/3-examples"},{"type":"function","title":"SwarmEx.create_network/1","doc":"Creates a new agent network with the given configuration.","ref":"SwarmEx.html#create_network/1"},{"type":"function","title":"Options - SwarmEx.create_network/1","doc":"* `:name` - Optional name for the network\n  * `:context` - Initial context map (default: %{})\n  * All other options are passed to the underlying Client","ref":"SwarmEx.html#create_network/1-options"},{"type":"function","title":"Examples - SwarmEx.create_network/1","doc":"{:ok, network} = SwarmEx.create_network()\n    {:ok, named_network} = SwarmEx.create_network(name: \"primary_network\")","ref":"SwarmEx.html#create_network/1-examples"},{"type":"function","title":"SwarmEx.list_agents/1","doc":"Lists all active agents in a network.","ref":"SwarmEx.html#list_agents/1"},{"type":"function","title":"Examples - SwarmEx.list_agents/1","doc":"{:ok, agent_ids} = SwarmEx.list_agents(network)","ref":"SwarmEx.html#list_agents/1-examples"},{"type":"function","title":"SwarmEx.register_tool/2","doc":"Registers a new tool that can be used by agents in the network.","ref":"SwarmEx.html#register_tool/2"},{"type":"function","title":"Examples - SwarmEx.register_tool/2","doc":"SwarmEx.register_tool(MyTool, max_retries: 3)","ref":"SwarmEx.html#register_tool/2-examples"},{"type":"function","title":"SwarmEx.send_message/3","doc":"Sends a message to an agent identified by ID within a network and waits for the response.","ref":"SwarmEx.html#send_message/3"},{"type":"function","title":"Examples - SwarmEx.send_message/3","doc":"{:ok, response} = SwarmEx.send_message(network, \"agent_id\", \"Process this\")","ref":"SwarmEx.html#send_message/3-examples"},{"type":"function","title":"SwarmEx.send_message_to_pid/2","doc":"Sends a message to an agent identified by PID and waits for the response.","ref":"SwarmEx.html#send_message_to_pid/2"},{"type":"function","title":"Examples - SwarmEx.send_message_to_pid/2","doc":"{:ok, response} = SwarmEx.send_message_to_pid(agent_pid, \"Process this\")","ref":"SwarmEx.html#send_message_to_pid/2-examples"},{"type":"function","title":"SwarmEx.stop_agent/2","doc":"Stops an agent and removes it from its network.","ref":"SwarmEx.html#stop_agent/2"},{"type":"function","title":"Examples - SwarmEx.stop_agent/2","doc":":ok = SwarmEx.stop_agent(agent)\n    :ok = SwarmEx.stop_agent(agent, :shutdown)","ref":"SwarmEx.html#stop_agent/2-examples"},{"type":"function","title":"SwarmEx.update_context/2","doc":"Updates the shared context for a network of agents.","ref":"SwarmEx.html#update_context/2"},{"type":"function","title":"Examples - SwarmEx.update_context/2","doc":":ok = SwarmEx.update_context(network, %{key: \"value\"})","ref":"SwarmEx.html#update_context/2-examples"},{"type":"function","title":"SwarmEx.version/0","doc":"Returns the version of the SwarmEx library.","ref":"SwarmEx.html#version/0"},{"type":"type","title":"SwarmEx.agent/0","doc":"","ref":"SwarmEx.html#t:agent/0"},{"type":"type","title":"SwarmEx.message/0","doc":"","ref":"SwarmEx.html#t:message/0"},{"type":"type","title":"SwarmEx.network/0","doc":"","ref":"SwarmEx.html#t:network/0"},{"type":"type","title":"SwarmEx.response/0","doc":"","ref":"SwarmEx.html#t:response/0"},{"type":"behaviour","title":"SwarmEx.Agent","doc":"Defines the behavior and implementation for SwarmEx agents.\n\nEach agent in the SwarmEx system is a process that can:\n- Process messages from other agents or clients\n- Execute tools and handle their results\n- Maintain internal state\n- Participate in agent networks","ref":"SwarmEx.Agent.html"},{"type":"behaviour","title":"Example - SwarmEx.Agent","doc":"defmodule MyAgent do\n      use SwarmEx.Agent\n\n      def init(opts) do\n        # Initialize agent state\n        {:ok, opts}\n      end\n\n      def handle_message(msg, state) do\n        # Handle incoming message\n        {:ok, response, state}\n      end\n\n      def handle_tool(tool_name, args, state) do\n        # Execute tool functionality\n        {:ok, result, state}\n      end\n    end","ref":"SwarmEx.Agent.html#module-example"},{"type":"function","title":"SwarmEx.Agent.create/2","doc":"Creates a new agent process with the given module and options.","ref":"SwarmEx.Agent.html#create/2"},{"type":"callback","title":"SwarmEx.Agent.handle_handoff/2","doc":"","ref":"SwarmEx.Agent.html#c:handle_handoff/2"},{"type":"callback","title":"SwarmEx.Agent.handle_message/2","doc":"","ref":"SwarmEx.Agent.html#c:handle_message/2"},{"type":"callback","title":"SwarmEx.Agent.handle_tool/3","doc":"","ref":"SwarmEx.Agent.html#c:handle_tool/3"},{"type":"function","title":"SwarmEx.Agent.stop/2","doc":"Stops an agent process.","ref":"SwarmEx.Agent.html#stop/2"},{"type":"function","title":"SwarmEx.Agent.validate_agent/1","doc":"Validates the agent implementation to ensure all required callbacks are implemented correctly.","ref":"SwarmEx.Agent.html#validate_agent/1"},{"type":"type","title":"SwarmEx.Agent.error/0","doc":"","ref":"SwarmEx.Agent.html#t:error/0"},{"type":"type","title":"SwarmEx.Agent.message/0","doc":"","ref":"SwarmEx.Agent.html#t:message/0"},{"type":"type","title":"SwarmEx.Agent.response/0","doc":"","ref":"SwarmEx.Agent.html#t:response/0"},{"type":"type","title":"SwarmEx.Agent.state/0","doc":"","ref":"SwarmEx.Agent.html#t:state/0"},{"type":"type","title":"SwarmEx.Agent.tool/0","doc":"","ref":"SwarmEx.Agent.html#t:tool/0"},{"type":"type","title":"SwarmEx.Agent.tool_args/0","doc":"","ref":"SwarmEx.Agent.html#t:tool_args/0"},{"type":"module","title":"SwarmEx.Application","doc":"The main SwarmEx application supervisor.\nResponsible for starting and supervising core system components.","ref":"SwarmEx.Application.html"},{"type":"module","title":"SwarmEx.Client","doc":"Main supervisor for agent networks. Manages agent lifecycles,\nmessage passing, error recovery and context variables.\n\nThe Client acts as a coordinator for a network of AI agents, handling:\n- Agent lifecycle management (creation, termination)\n- Message routing between agents\n- Network state and context maintenance\n- Error handling and recovery","ref":"SwarmEx.Client.html"},{"type":"function","title":"SwarmEx.Client.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"SwarmEx.Client.html#child_spec/1"},{"type":"function","title":"SwarmEx.Client.create_agent/3","doc":"Creates a new agent in the network.","ref":"SwarmEx.Client.html#create_agent/3"},{"type":"function","title":"Options - SwarmEx.Client.create_agent/3","doc":"All options are passed to the agent's init function.","ref":"SwarmEx.Client.html#create_agent/3-options"},{"type":"function","title":"SwarmEx.Client.list_agents/1","doc":"Lists all active agents in the network.","ref":"SwarmEx.Client.html#list_agents/1"},{"type":"function","title":"SwarmEx.Client.send_message/3","doc":"Sends a message to a specific agent in the network.","ref":"SwarmEx.Client.html#send_message/3"},{"type":"function","title":"SwarmEx.Client.start_link/1","doc":"Starts a new agent network with the given options.","ref":"SwarmEx.Client.html#start_link/1"},{"type":"function","title":"Options - SwarmEx.Client.start_link/1","doc":"* `:network_id` - Custom identifier for the network (optional)\n  * `:context` - Initial context map (default: %{})\n  * `:registry` - Custom registry for agent processes (optional)","ref":"SwarmEx.Client.html#start_link/1-options"},{"type":"function","title":"SwarmEx.Client.update_context/2","doc":"Updates the network context with new values.","ref":"SwarmEx.Client.html#update_context/2"},{"type":"type","title":"SwarmEx.Client.t/0","doc":"","ref":"SwarmEx.Client.html#t:t/0"},{"type":"module","title":"SwarmEx.Error","doc":"Defines custom error types and error handling utilities for SwarmEx.\n\nThis module provides a set of error exceptions specific to different failure modes\nin the SwarmEx system, along with helper functions for error handling and formatting.","ref":"SwarmEx.Error.html"},{"type":"function","title":"SwarmEx.Error.create_error_context/1","doc":"Creates a standardized error context map.","ref":"SwarmEx.Error.html#create_error_context/1"},{"type":"function","title":"SwarmEx.Error.generate_correlation_id/0","doc":"Generates a correlation ID for error tracking.","ref":"SwarmEx.Error.html#generate_correlation_id/0"},{"type":"type","title":"SwarmEx.Error.error_context/0","doc":"","ref":"SwarmEx.Error.html#t:error_context/0"},{"type":"type","title":"SwarmEx.Error.error_severity/0","doc":"","ref":"SwarmEx.Error.html#t:error_severity/0"},{"type":"type","title":"SwarmEx.Error.error_type/0","doc":"","ref":"SwarmEx.Error.html#t:error_type/0"},{"type":"module","title":"SwarmEx.Telemetry","doc":"Telemetry integration for SwarmEx.\nProvides metrics and event tracking for agent activities.","ref":"SwarmEx.Telemetry.html"},{"type":"module","title":"Events - SwarmEx.Telemetry","doc":"The following events are emitted:\n\n* `[:swarm_ex, :agent, :message, :start]` - When an agent begins processing a message\n  * Measurement: `:system_time`\n  * Metadata: `:agent_id`, `:message_type`, `:network_id`\n\n* `[:swarm_ex, :agent, :message, :stop]` - When an agent completes processing a message\n  * Measurement: `:duration`, `:queue_time`\n  * Metadata: `:agent_id`, `:message_type`, `:network_id`, `:result`\n\n* `[:swarm_ex, :tool, :execute, :start]` - When a tool execution begins\n  * Measurement: `:system_time`\n  * Metadata: `:tool_name`, `:agent_id`, `:args`\n\n* `[:swarm_ex, :tool, :execute, :stop]` - When a tool execution completes\n  * Measurement: `:duration`\n  * Metadata: `:tool_name`, `:agent_id`, `:result`","ref":"SwarmEx.Telemetry.html#module-events"},{"type":"function","title":"SwarmEx.Telemetry.attach/0","doc":"Attaches telemetry event handlers. Call this when your application starts.","ref":"SwarmEx.Telemetry.html#attach/0"},{"type":"function","title":"SwarmEx.Telemetry.span_agent_message/3","doc":"Emits an agent message event with timing information.","ref":"SwarmEx.Telemetry.html#span_agent_message/3"},{"type":"function","title":"SwarmEx.Telemetry.span_tool_execution/4","doc":"Emits a tool execution event with timing information.","ref":"SwarmEx.Telemetry.html#span_tool_execution/4"},{"type":"behaviour","title":"SwarmEx.Tool","doc":"Defines the behavior and functionality for agent tools.\n\nTools are capabilities that agents can use to perform specific tasks. Each tool\nmust implement this behavior to be usable within the SwarmEx system.","ref":"SwarmEx.Tool.html"},{"type":"behaviour","title":"Tool Configuration - SwarmEx.Tool","doc":"Tools can be configured with the following options:\n  * `:timeout` - Maximum time in milliseconds to wait for tool execution (default: 5000)\n  * `:retries` - Number of retry attempts for failed executions (default: 3)\n  * `:validate_args` - Whether to validate arguments before execution (default: true)","ref":"SwarmEx.Tool.html#module-tool-configuration"},{"type":"behaviour","title":"Example - SwarmEx.Tool","doc":"defmodule MyTool do\n      @behaviour SwarmEx.Tool\n\n      @impl true\n      def execute(args) do\n        # Perform tool operation\n        {:ok, result}\n      end\n\n      @impl true\n      def validate(args) do\n        # Validate incoming arguments\n        :ok\n      end\n\n      @impl true\n      def cleanup(args) do\n        # Cleanup any resources\n        :ok\n      end\n    end","ref":"SwarmEx.Tool.html#module-example"},{"type":"callback","title":"SwarmEx.Tool.cleanup/1","doc":"","ref":"SwarmEx.Tool.html#c:cleanup/1"},{"type":"callback","title":"SwarmEx.Tool.execute/1","doc":"","ref":"SwarmEx.Tool.html#c:execute/1"},{"type":"function","title":"SwarmEx.Tool.execute/3","doc":"Safely executes a tool with the given arguments and options.","ref":"SwarmEx.Tool.html#execute/3"},{"type":"function","title":"Options - SwarmEx.Tool.execute/3","doc":"* `:timeout` - Maximum time in milliseconds to wait (default: 5000)\n  * `:retries` - Number of retry attempts (default: 3)\n  * `:validate_args` - Whether to validate arguments (default: true)","ref":"SwarmEx.Tool.html#execute/3-options"},{"type":"function","title":"Examples - SwarmEx.Tool.execute/3","doc":"iex> SwarmEx.Tool.execute(MyTool, args, timeout: 10_000)\n    {:ok, result}\n\n    iex> SwarmEx.Tool.execute(InvalidTool, bad_args)\n    {:error, :validation_failed}","ref":"SwarmEx.Tool.html#execute/3-examples"},{"type":"function","title":"SwarmEx.Tool.get_config/1","doc":"Retrieves the configuration for a registered tool.","ref":"SwarmEx.Tool.html#get_config/1"},{"type":"function","title":"Examples - SwarmEx.Tool.get_config/1","doc":"iex> SwarmEx.Tool.get_config(MyTool)\n    {:ok, [max_retries: 5]}\n\n    iex> SwarmEx.Tool.get_config(UnregisteredTool)\n    {:error, :not_registered}","ref":"SwarmEx.Tool.html#get_config/1-examples"},{"type":"function","title":"SwarmEx.Tool.register/2","doc":"Registers a tool configuration in the runtime.\nThis allows for dynamic tool configuration and validation.","ref":"SwarmEx.Tool.html#register/2"},{"type":"function","title":"Examples - SwarmEx.Tool.register/2","doc":"iex> SwarmEx.Tool.register(MyTool, max_retries: 5)\n    :ok","ref":"SwarmEx.Tool.html#register/2-examples"},{"type":"callback","title":"SwarmEx.Tool.validate/1","doc":"","ref":"SwarmEx.Tool.html#c:validate/1"},{"type":"function","title":"SwarmEx.Tool.validate_tool/1","doc":"Validates that a module implements the Tool behavior correctly.\n\nReturns `:ok` if the tool is valid, `{:error, reason}` otherwise.","ref":"SwarmEx.Tool.html#validate_tool/1"},{"type":"function","title":"Examples - SwarmEx.Tool.validate_tool/1","doc":"iex> SwarmEx.Tool.validate_tool(MyTool)\n    :ok\n\n    iex> SwarmEx.Tool.validate_tool(InvalidModule)\n    {:error, :invalid_tool}","ref":"SwarmEx.Tool.html#validate_tool/1-examples"},{"type":"type","title":"SwarmEx.Tool.args/0","doc":"","ref":"SwarmEx.Tool.html#t:args/0"},{"type":"type","title":"SwarmEx.Tool.cleanup_result/0","doc":"","ref":"SwarmEx.Tool.html#t:cleanup_result/0"},{"type":"type","title":"SwarmEx.Tool.options/0","doc":"","ref":"SwarmEx.Tool.html#t:options/0"},{"type":"type","title":"SwarmEx.Tool.result/0","doc":"","ref":"SwarmEx.Tool.html#t:result/0"},{"type":"type","title":"SwarmEx.Tool.t/0","doc":"","ref":"SwarmEx.Tool.html#t:t/0"},{"type":"type","title":"SwarmEx.Tool.validation_result/0","doc":"","ref":"SwarmEx.Tool.html#t:validation_result/0"},{"type":"module","title":"SwarmEx.Tools.CodeInterpreter","doc":"A tool for executing code snippets in a sandboxed environment.\nSupports Python and Elixir code execution.","ref":"SwarmEx.Tools.CodeInterpreter.html"},{"type":"type","title":"SwarmEx.Tools.CodeInterpreter.code_block/0","doc":"","ref":"SwarmEx.Tools.CodeInterpreter.html#t:code_block/0"},{"type":"module","title":"SwarmEx.Tools.Retrieval","doc":"A tool for retrieving and searching through documents and other content.\nSupports various data sources and search strategies.","ref":"SwarmEx.Tools.Retrieval.html"},{"type":"type","title":"SwarmEx.Tools.Retrieval.query/0","doc":"","ref":"SwarmEx.Tools.Retrieval.html#t:query/0"},{"type":"type","title":"SwarmEx.Tools.Retrieval.retrieval_result/0","doc":"","ref":"SwarmEx.Tools.Retrieval.html#t:retrieval_result/0"},{"type":"module","title":"SwarmEx.Utils","doc":"Utility functions for SwarmEx operations.\nProvides helper functions for common operations across the library.","ref":"SwarmEx.Utils.html"},{"type":"function","title":"SwarmEx.Utils.deep_merge/2","doc":"Deep merges two maps recursively. If the same key exists in both maps\nand both values are maps, they are merged recursively. Otherwise, the\nvalue from the second map takes precedence.","ref":"SwarmEx.Utils.html#deep_merge/2"},{"type":"function","title":"Examples - SwarmEx.Utils.deep_merge/2","doc":"iex> deep_merge(%{a: 1, b: %{c: 2}}, %{b: %{d: 3}, e: 4})\n    %{a: 1, b: %{c: 2, d: 3}, e: 4}\n\n    iex> deep_merge(%{a: %{b: 1}}, %{a: 2})\n    %{a: 2}","ref":"SwarmEx.Utils.html#deep_merge/2-examples"},{"type":"function","title":"SwarmEx.Utils.deserialize/1","doc":"Deserializes a string back into a term.","ref":"SwarmEx.Utils.html#deserialize/1"},{"type":"function","title":"Examples - SwarmEx.Utils.deserialize/1","doc":"iex> deserialize(\"{\":name\":\"John\",\":age\":30}\")\n    {:ok, %{name: \"John\", age: 30}}\n\n    iex> deserialize(\"invalid json\")\n    {:error, :invalid_json}","ref":"SwarmEx.Utils.html#deserialize/1-examples"},{"type":"function","title":"SwarmEx.Utils.format_error/1","doc":"Formats an error tuple into a standardized error structure.","ref":"SwarmEx.Utils.html#format_error/1"},{"type":"function","title":"Examples - SwarmEx.Utils.format_error/1","doc":"iex> format_error({:error, \"Something went wrong\"})\n    %SwarmEx.Error.AgentError{message: \"Something went wrong\", reason: :unknown}\n\n    iex> format_error(%RuntimeError{message: \"Oops\"})\n    %SwarmEx.Error.AgentError{message: \"Oops\", reason: :runtime_error}","ref":"SwarmEx.Utils.html#format_error/1-examples"},{"type":"function","title":"SwarmEx.Utils.generate_id/1","doc":"Generates a unique identifier with an optional prefix.","ref":"SwarmEx.Utils.html#generate_id/1"},{"type":"function","title":"Examples - SwarmEx.Utils.generate_id/1","doc":"iex> generate_id()\n    \"c1dd6960-7b91-4ca1-b853-c01c7f24d1aa\"\n\n    iex> generate_id(\"user\")\n    \"user_c1dd6960-7b91-4ca1-b853-c01c7f24d1aa\"","ref":"SwarmEx.Utils.html#generate_id/1-examples"},{"type":"function","title":"SwarmEx.Utils.log/3","doc":"Logs a message with additional context and metadata.\nEnsures consistent log formatting across the application.","ref":"SwarmEx.Utils.html#log/3"},{"type":"function","title":"Examples - SwarmEx.Utils.log/3","doc":"iex> log(:info, \"Processing message\", agent_id: \"123\")\n    :ok\n\n    iex> log(:error, \"Failed to process\", [error: \"timeout\", agent_id: \"123\"])\n    :ok","ref":"SwarmEx.Utils.html#log/3-examples"},{"type":"function","title":"SwarmEx.Utils.safely_execute/2","doc":"Safely executes a function with timeout and retry logic.","ref":"SwarmEx.Utils.html#safely_execute/2"},{"type":"function","title":"Options - SwarmEx.Utils.safely_execute/2","doc":"* `:timeout` - Maximum time in milliseconds to wait for each attempt (default: 5000)\n  * `:retries` - Number of retry attempts (default: 3)\n  * `:backoff_base` - Base time in milliseconds for backoff calculation (default: 100)\n  * `:backoff_type` - Type of backoff, either :exponential or :linear (default: :exponential)","ref":"SwarmEx.Utils.html#safely_execute/2-options"},{"type":"function","title":"Examples - SwarmEx.Utils.safely_execute/2","doc":"iex> safely_execute(fn -> {:ok, :success} end)\n    {:ok, :success}\n\n    iex> safely_execute(fn -> raise \"error\" end)\n    {:error, %RuntimeError{message: \"error\"}}","ref":"SwarmEx.Utils.html#safely_execute/2-examples"},{"type":"function","title":"SwarmEx.Utils.serialize/1","doc":"Serializes a term into a string representation.","ref":"SwarmEx.Utils.html#serialize/1"},{"type":"function","title":"Examples - SwarmEx.Utils.serialize/1","doc":"iex> serialize(%{name: \"John\", age: 30})\n    {:ok, \"{\":name\":\"John\",\":age\":30}\"}\n\n    iex> serialize(%{invalid: make_ref()})\n    {:error, :unserializable_term}","ref":"SwarmEx.Utils.html#serialize/1-examples"},{"type":"function","title":"SwarmEx.Utils.validate_schema/2","doc":"Validates a map against a schema of required and optional keys.","ref":"SwarmEx.Utils.html#validate_schema/2"},{"type":"function","title":"Examples - SwarmEx.Utils.validate_schema/2","doc":"iex> schema = [required: [:name, :age], optional: [:email]]\n    iex> validate_schema(%{name: \"John\", age: 30}, schema)\n    :ok\n\n    iex> validate_schema(%{name: \"John\"}, [required: [:name, :age]])\n    {:error, {:missing_required_keys, [:age]}}","ref":"SwarmEx.Utils.html#validate_schema/2-examples"},{"type":"type","title":"SwarmEx.Utils.retry_opts/0","doc":"","ref":"SwarmEx.Utils.html#t:retry_opts/0"},{"type":"exception","title":"SwarmEx.Error.AgentError","doc":"Raised when an agent encounters an error during operation.\n\nThis error indicates issues with agent execution, including:\n- Initialization failures\n- Message handling errors\n- State corruption\n- Resource exhaustion","ref":"SwarmEx.Error.AgentError.html"},{"type":"type","title":"SwarmEx.Error.AgentError.t/0","doc":"","ref":"SwarmEx.Error.AgentError.html#t:t/0"},{"type":"exception","title":"SwarmEx.Error.HandoffError","doc":"Raised when an agent handoff operation fails.\n\nThis error indicates a failure in transferring control or state between agents.\nCommon causes include:\n- Network connectivity issues\n- State serialization failures\n- Target agent unavailability","ref":"SwarmEx.Error.HandoffError.html"},{"type":"type","title":"SwarmEx.Error.HandoffError.t/0","doc":"","ref":"SwarmEx.Error.HandoffError.html#t:t/0"},{"type":"exception","title":"SwarmEx.Error.NetworkError","doc":"Raised when an error occurs at the network level.\n\nThis error represents system-wide or network-level issues, including:\n- Node communication failures\n- Network partitions\n- Supervisor failures\n- Configuration errors","ref":"SwarmEx.Error.NetworkError.html"},{"type":"type","title":"SwarmEx.Error.NetworkError.t/0","doc":"","ref":"SwarmEx.Error.NetworkError.html#t:t/0"},{"type":"exception","title":"SwarmEx.Error.ToolExecutionError","doc":"Raised when a tool execution fails.\n\nThis error represents failures in tool operations, which may include:\n- Invalid tool parameters\n- Tool timeouts\n- Resource unavailability\n- Internal tool errors","ref":"SwarmEx.Error.ToolExecutionError.html"},{"type":"type","title":"SwarmEx.Error.ToolExecutionError.t/0","doc":"","ref":"SwarmEx.Error.ToolExecutionError.html#t:t/0"},{"type":"extras","title":"SwarmEx  🐝 🐝 🐝","doc":"# SwarmEx  🐝 🐝 🐝\n\nSwarmEx is an Elixir library for lightweight, controllable, and testable AI agent orchestration. It provides primitives for creating and coordinating networks of AI agents, leveraging Elixir's native strengths in concurrency and fault tolerance.","ref":"readme.html"},{"type":"extras","title":"Installation - SwarmEx  🐝 🐝 🐝","doc":"The package can be installed by adding `swarm_ex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:swarm_ex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Features - SwarmEx  🐝 🐝 🐝","doc":"- Lightweight agent orchestration\n- Tool integration framework\n- Built-in telemetry and observability\n- Robust error handling\n- Clear developer experience","ref":"readme.html#features"},{"type":"extras","title":"Quick Start - SwarmEx  🐝 🐝 🐝","doc":"[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fraw.githubusercontent.com%2Fnrrso%2Fswarm_ex%2Frefs%2Fheads%2Fmain%2Flivebooks%2Fswarm_ex.livemd)","ref":"readme.html#quick-start"},{"type":"extras","title":"Documentation - SwarmEx  🐝 🐝 🐝","doc":"The docs can be found at [https://hexdocs.pm/swarm_ex](https://hexdocs.pm/swarm_ex).","ref":"readme.html#documentation"},{"type":"extras","title":"Testing - SwarmEx  🐝 🐝 🐝","doc":"```bash\nmix test\n```","ref":"readme.html#testing"},{"type":"extras","title":"Contributing - SwarmEx  🐝 🐝 🐝","doc":"1. Fork it\n2. Create your feature branch (`git checkout -b feature/my-new-feature`)\n3. Commit your changes (`git commit -am 'Add some feature'`)\n4. Push to the branch (`git push origin feature/my-new-feature`)\n5. Create new Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - SwarmEx  🐝 🐝 🐝","doc":"Apache License 2.0 - See LICENSE for details.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}